@@ -11,7 +11,7 @@ use ExtUtils::Installed ;
 use File::Spec ;
 
 
-our $VERSION = '0.07' ;
+our $VERSION = '0.08' ;
 
 @autodynaload::INC = () ;
 autodynaload->new($autodynaload::dl_findfile)->insert(-1) ;
@@ -53,6 +53,7 @@ sub _bootstrap_inherit {
 	package DynaLoader;
 
 	my $module = $_[0];
+	no strict 'refs' ;
 	local *DynaLoader::isa = *{"$module\::ISA"};
 	local @DynaLoader::isa = (@DynaLoader::isa, 'DynaLoader');
 	# Cannot goto due to delocalization.  Will report errors on a wrong line?
@@ -164,7 +165,7 @@ BEGIN {
 	*{'DynaLoader::bootstrap'} = \&autodynaload::_bootstrap ;
 	*{'DynaLoader::dl_findfile'} = \&autodynaload::_dl_findfile ;
 	# Force XSLoader to use DynaLoader
-	*{'XSLoader::load'} = \&autodynaload::bootstrap_inherit ;
+	*{'XSLoader::load'} = \&autodynaload::_bootstrap_inherit ;
 }
 
 
